-- =============================================
-- SaveToDB Framework for PostgreSQL
-- Version 7.19, March 12, 2018
--
-- Copyright 2015-2018 Gartle Technology Corporation
-- =============================================

-- Create the plpgsql language if it is not exist

-- CREATE LANGUAGE plpgsql;

CREATE SCHEMA savetodb_dev;
CREATE SCHEMA savetodb_xls;

-- print Schemas have been created

CREATE TABLE savetodb_dev.query_list (
    id serial NOT NULL,
    table_schema varchar(63) NOT NULL,
    table_name varchar(63) NOT NULL,
    table_type varchar(63) NOT NULL,
    table_code text,
    insert_procedure text,
    update_procedure text,
    delete_procedure text,
    procedure_type varchar(63),
    PRIMARY KEY (id)
);

CREATE OR REPLACE VIEW savetodb_dev.view_query_list
AS
SELECT
    t.table_schema
    , t.table_name
    , t.table_type
    , NULL AS table_code
    , COALESCE(q.insert_procedure, CASE WHEN i.routine_name IS NULL THEN NULL ELSE i.routine_schema || '.' || i.routine_name END) AS insert_procedure
    , COALESCE(q.update_procedure, CASE WHEN u.routine_name IS NULL THEN NULL ELSE u.routine_schema || '.' || u.routine_name END) AS update_procedure
    , COALESCE(q.delete_procedure, CASE WHEN d.routine_name IS NULL THEN NULL ELSE d.routine_schema || '.' || d.routine_name END) AS delete_procedure
    , COALESCE(q.procedure_type, CASE WHEN i.routine_name IS NOT NULL THEN 'FUNCTION' ELSE NULL END) AS procedure_type
FROM
    information_schema.tables t
    LEFT OUTER JOIN information_schema.routines i ON i.routine_schema = t.table_schema AND i.routine_name = replace(t.table_name, '_select', '') || '_insert'
    LEFT OUTER JOIN information_schema.routines u ON u.routine_schema = t.table_schema AND u.routine_name = replace(t.table_name, '_select', '') || '_update'
    LEFT OUTER JOIN information_schema.routines d ON d.routine_schema = t.table_schema AND d.routine_name = replace(t.table_name, '_select', '') || '_delete'
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.table_schema = t.table_schema AND q.table_name = t.table_name
WHERE
    NOT t.table_schema IN ('information_schema', 'pg_catalog')
UNION
SELECT
    r.routine_schema AS table_schema
    , r.routine_name AS table_name
    , r.routine_type AS table_type
    , NULL AS table_code
    , COALESCE(q.insert_procedure, CASE WHEN i.routine_name IS NULL THEN NULL ELSE i.routine_schema || '.' || i.routine_name END) AS insert_procedure
    , COALESCE(q.update_procedure, CASE WHEN u.routine_name IS NULL THEN NULL ELSE u.routine_schema || '.' || u.routine_name END) AS update_procedure
    , COALESCE(q.delete_procedure, CASE WHEN d.routine_name IS NULL THEN NULL ELSE d.routine_schema || '.' || d.routine_name END) AS delete_procedure
    , COALESCE(q.procedure_type, CASE WHEN i.routine_name IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS procedure_type
FROM 
    information_schema.routines r
    LEFT OUTER JOIN information_schema.routines i ON i.routine_schema = r.routine_schema AND i.routine_name = replace(r.routine_name, '_select', '') || '_insert'
    LEFT OUTER JOIN information_schema.routines u ON u.routine_schema = r.routine_schema AND u.routine_name = replace(r.routine_name, '_select', '') || '_update'
    LEFT OUTER JOIN information_schema.routines d ON d.routine_schema = r.routine_schema AND d.routine_name = replace(r.routine_name, '_select', '') || '_delete'
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.table_schema = r.routine_schema AND q.table_name = r.routine_name
WHERE
    NOT r.routine_schema IN ('information_schema', 'pg_catalog')
    AND r.routine_type = 'FUNCTION'
    AND NOT (
        r.routine_name LIKE '%_insert'
        OR r.routine_name LIKE '%_update'
        OR r.routine_name LIKE '%_delete'
        OR r.routine_name LIKE '%_merge'
        OR r.routine_name LIKE '%_change'
    )
UNION
SELECT
    q.table_schema
    , q.table_name
    , q.table_type
    , q.table_code
    , q.insert_procedure
    , q.update_procedure
    , q.delete_procedure
    , q.procedure_type
FROM
    savetodb_dev.query_list q
    LEFT OUTER JOIN information_schema.tables t ON q.table_schema = t.table_schema AND q.table_name = t.table_name
    LEFT OUTER JOIN information_schema.routines r ON q.table_schema = r.routine_schema AND q.table_name = r.routine_name
WHERE
    q.table_type IN ('CODE', 'HTTP', 'TEXT')
    AND t.table_name IS NULL
    AND r.routine_name IS NULL
ORDER BY
    table_schema
    , table_name;
    
CREATE OR REPLACE VIEW savetodb_xls.view_query_list
AS
SELECT
    t.table_schema
    , t.table_name
    , t.table_type
    , t.table_code
    , t.insert_procedure
    , t.update_procedure
    , t.delete_procedure
    , t.procedure_type
FROM
    savetodb_dev.view_query_list t
WHERE
    NOT t.table_schema IN ('savetodb_dev')
    AND NOT t.table_name IN (
        'view_column_translation'
        , 'view_object_translation'
        , 'view_event_handlers'
        , 'view_table_formats'
        , 'view_parameter_values'
        , 'view_query_list'
        )
    AND NOT t.table_name LIKE 'xl_%'
ORDER BY
    table_schema
    , table_name;
    
-- print QueryList objects have been created

CREATE TABLE savetodb_dev.object_translation (
    id serial NOT NULL,
    table_schema varchar(63) NOT NULL,
    table_name varchar(63) NOT NULL,
    language_name character(2) NOT NULL,
    translated_name varchar(63),
    translated_desc varchar(256),
    translated_comment varchar(2000),
    PRIMARY KEY (id)
);

CREATE UNIQUE INDEX ix_schema_name_language ON savetodb_dev.object_translation
    USING BTREE (
        table_schema,
        table_name,
        language_name
    );

CREATE TABLE savetodb_dev.column_translation (
    id serial NOT NULL,
    table_schema varchar(63),
    table_name varchar(63),
    column_name varchar(63) NOT NULL,
    language_name character(2) NOT NULL,
    translated_name varchar(63),
    translated_desc varchar(1024),
    PRIMARY KEY (id)
);

CREATE UNIQUE INDEX ix_schema_name_column_language ON savetodb_dev.column_translation
    USING BTREE (
        table_schema,
        table_name,
        column_name,
        language_name
    );
    
CREATE VIEW savetodb_xls.view_object_translation
AS
SELECT
    t.id,
    t.table_schema,
    t.table_name,
    t.language_name,
    t.translated_name,
    t.translated_desc,
    t.translated_comment
FROM
    savetodb_dev.object_translation t;

CREATE VIEW savetodb_xls.view_column_translation
AS
SELECT
    t.id,
    t.table_schema,
    t.table_name,
    t.column_name,
    t.language_name,
    t.translated_name,
    t.translated_desc
FROM
    savetodb_dev.column_translation t;

CREATE VIEW savetodb_xls.view_object_description
AS
SELECT
    t.id
    , t.language_name
    , t.table_schema
    , t.table_name
    , t.translated_name
    , t.translated_comment
FROM
    savetodb_dev.object_translation t
WHERE
    t.translated_name IS NOT NULL
    AND t.translated_comment IS NOT NULL
    AND NOT t.table_schema IN ('information_schema', 'pg_catalog', 'savetodb_dev', 'savetodb_xls')
    AND NOT t.table_name LIKE '%_insert'
    AND NOT t.table_name LIKE '%_update'
    AND NOT t.table_name LIKE '%_delete'
    AND NOT t.table_name LIKE '%_merge'
    AND NOT t.table_name LIKE 'xl_%'
;

-- print Translation objects have been created

CREATE TABLE savetodb_dev.event_handlers (
    id serial NOT NULL,
    table_schema varchar(63) NOT NULL,
    table_name varchar(63) NOT NULL,
    column_name varchar(63),
    event_name varchar(50) NOT NULL,
    handler_schema varchar(63),
    handler_name varchar(63),
    handler_type varchar(63),
    handler_code text,
    target_worksheet varchar(256),
    menu_order smallint,
    edit_parameters boolean,
    is_active boolean,
    PRIMARY KEY (id)
);

CREATE OR REPLACE VIEW savetodb_xls.view_event_handlers
AS
SELECT
    t.id,
    t.table_schema,
    t.table_name,
    t.column_name,
    t.event_name,
    t.handler_schema,
    t.handler_name,
    t.handler_type,
    t.handler_code,
    t.target_worksheet,
    t.menu_order,
    t.edit_parameters
FROM
    savetodb_dev.event_handlers t
WHERE
    COALESCE(t.is_active, TRUE) = TRUE;

-- print EventHandlers objects have been created

CREATE TABLE savetodb_dev.parameter_values
(
    id serial NOT NULL,
    table_schema varchar(63) NOT NULL,
    table_name varchar(63) NOT NULL,
    parameter_name varchar(63) NOT NULL,
    select_schema varchar(63),
    select_name varchar(63) NOT NULL,
    select_type varchar(63),
    select_code text,
    PRIMARY KEY (id)
);

CREATE UNIQUE INDEX ix_schema_name_parameter ON savetodb_dev.parameter_values
    USING BTREE (
        table_schema,
        table_name,
        parameter_name
    );
    
CREATE OR REPLACE VIEW savetodb_xls.view_parameter_values
AS
SELECT 
    t.id,
    t.table_schema,
    t.table_name,
    t.parameter_name,
    t.select_schema,
    t.select_name,
    t.select_type,
    t.select_code
FROM 
    savetodb_dev.parameter_values t;

-- print ParameterValues  objects have been created

CREATE TABLE savetodb_dev.table_formats (
    id serial NOT NULL,
    table_schema varchar(63) NOT NULL,
    table_name varchar(63) NOT NULL,
    table_excel_format_xml text,
    PRIMARY KEY (id)
);

CREATE UNIQUE INDEX ix_table_formats_schema_name ON savetodb_dev.table_formats
    USING BTREE (
        table_schema, 
        table_name
    );
    
CREATE OR REPLACE VIEW savetodb_xls.view_table_formats
AS
SELECT
    t.id,
    t.table_schema,
    t.table_name,
    t.table_excel_format_xml
FROM
    savetodb_dev.table_formats t;

CREATE FUNCTION savetodb_dev.table_format_save (
    Schema varchar(63),
    Name varchar(63),
    ExcelFormatXML text
    )
RETURNS VOID AS $$
DECLARE RowCount integer;
BEGIN
IF Schema IS NOT NULL AND Name IS NOT NULL THEN
    IF ExcelFormatXML IS NULL THEN
        DELETE FROM savetodb_dev.table_formats
        WHERE
            table_schema = Schema AND table_name = Name;
    ELSE
        SELECT COUNT(*) INTO RowCount
        FROM savetodb_dev.table_formats
        WHERE
            table_schema = Schema AND table_name = Name;

        IF (RowCount = 0) THEN
            INSERT INTO savetodb_dev.table_formats
                (table_schema, table_name, table_excel_format_xml)
            VALUES
                (Schema, Name, ExcelFormatXML);
        ELSE
            UPDATE savetodb_dev.table_formats
            SET
                table_schema = Schema,
                table_name = Name,
                table_excel_format_xml = ExcelFormatXML
            WHERE
                table_schema = Schema AND table_name = Name;
        END IF;
    END IF;
END IF;
END
$$ LANGUAGE plpgsql;

-- print TableFormats objects have been created

CREATE ROLE savetodb_xls_role;
CREATE ROLE savetodb_dev_role;

GRANT USAGE ON SCHEMA savetodb_xls TO savetodb_xls_role;
GRANT USAGE ON SCHEMA savetodb_xls TO savetodb_dev_role;
GRANT USAGE ON SCHEMA savetodb_dev TO savetodb_dev_role;

-- These commands are not supported in PostgreSQL 8.x

-- GRANT SELECT ON ALL TABLES                          IN SCHEMA savetodb_xls TO savetodb_xls_role;
-- GRANT SELECT ON ALL TABLES                          IN SCHEMA savetodb_xls TO savetodb_dev_role;
-- GRANT SELECT, INSERT, UPDATE, DELETE ON ALL TABLES  IN SCHEMA savetodb_dev TO savetodb_dev_role;

-- GRANT EXECUTE ON ALL FUNCTIONS                      IN SCHEMA savetodb_xls TO savetodb_xls_role;
-- GRANT EXECUTE ON ALL FUNCTIONS                      IN SCHEMA savetodb_xls TO savetodb_dev_role;
-- GRANT EXECUTE ON ALL FUNCTIONS                      IN SCHEMA savetodb_dev TO savetodb_dev_role;

-- These commands are applied by objects for compatibility with PostgreSQL 8.x

GRANT SELECT ON TABLE savetodb_xls.view_query_list          TO savetodb_xls_role;
GRANT SELECT ON TABLE savetodb_xls.view_event_handlers      TO savetodb_xls_role;
GRANT SELECT ON TABLE savetodb_xls.view_parameter_values    TO savetodb_xls_role;
GRANT SELECT ON TABLE savetodb_xls.view_column_translation  TO savetodb_xls_role;
GRANT SELECT ON TABLE savetodb_xls.view_object_translation  TO savetodb_xls_role;
GRANT SELECT ON TABLE savetodb_xls.view_object_description  TO savetodb_xls_role;
GRANT SELECT ON TABLE savetodb_xls.view_table_formats       TO savetodb_xls_role;

GRANT SELECT ON TABLE savetodb_dev.view_query_list          TO savetodb_dev_role;
GRANT SELECT ON TABLE savetodb_xls.view_query_list          TO savetodb_dev_role;

GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_xls.view_event_handlers      TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_xls.view_parameter_values    TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_xls.view_column_translation  TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_xls.view_object_translation  TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_xls.view_object_description  TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_xls.view_table_formats       TO savetodb_dev_role;

GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_dev.query_list           TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_dev.event_handlers       TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_dev.parameter_values     TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_dev.object_translation   TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_dev.column_translation   TO savetodb_dev_role;
GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE savetodb_dev.table_formats        TO savetodb_dev_role;

GRANT EXECUTE ON FUNCTION savetodb_dev.table_format_save(schema character varying, name character varying, excelformatxml text) TO savetodb_dev_role;

-- print Roles have been created

INSERT INTO savetodb_dev.query_list (table_schema, table_name, table_type, table_code, insert_procedure, update_procedure, delete_procedure, procedure_type) VALUES ('savetodb_xls', 'view_table_formats',      'VIEW', NULL, 'savetodb_dev.table_formats', 'savetodb_dev.table_formats', 'savetodb_dev.table_formats', 'TABLE');
INSERT INTO savetodb_dev.query_list (table_schema, table_name, table_type, table_code, insert_procedure, update_procedure, delete_procedure, procedure_type) VALUES ('savetodb_xls', 'view_parameter_values',   'VIEW', NULL, 'savetodb_dev.parameter_values', 'savetodb_dev.parameter_values', 'savetodb_dev.parameter_values', 'TABLE');
INSERT INTO savetodb_dev.query_list (table_schema, table_name, table_type, table_code, insert_procedure, update_procedure, delete_procedure, procedure_type) VALUES ('savetodb_xls', 'view_event_handlers',     'VIEW', NULL, 'savetodb_dev.event_handlers', 'savetodb_dev.event_handlers', 'savetodb_dev.event_handlers', 'TABLE');
INSERT INTO savetodb_dev.query_list (table_schema, table_name, table_type, table_code, insert_procedure, update_procedure, delete_procedure, procedure_type) VALUES ('savetodb_xls', 'view_object_description', 'VIEW', NULL, 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'TABLE');
INSERT INTO savetodb_dev.query_list (table_schema, table_name, table_type, table_code, insert_procedure, update_procedure, delete_procedure, procedure_type) VALUES ('savetodb_xls', 'view_object_translation', 'VIEW', NULL, 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'TABLE');
INSERT INTO savetodb_dev.query_list (table_schema, table_name, table_type, table_code, insert_procedure, update_procedure, delete_procedure, procedure_type) VALUES ('savetodb_xls', 'view_column_translation', 'VIEW', NULL, 'savetodb_dev.column_translation', 'savetodb_dev.column_translation', 'savetodb_dev.column_translation', 'TABLE');

INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_dev','column_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_dev','object_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_dev','event_handlers',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-event-handlers.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_dev','parameter_values',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-parameter-values.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_dev','query_list',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_dev','table_formats',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-table-formats.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_xls','view_column_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_xls','view_object_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_xls','view_event_handlers',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-event-handlers.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_xls','view_parameter_values',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-parameter-values.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_dev','view_query_list',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_xls','view_query_list',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code, target_worksheet, menu_order, edit_parameters) VALUES ('savetodb_xls','view_table_formats',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-table-formats.htm',NULL,11,NULL);

INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);
INSERT INTO savetodb_dev.event_handlers (table_schema, table_name, column_name, event_name, handler_schema, handler_name, handler_type, handler_code) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);

INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_dev', 'column_translation', 'en', NULL, 'Configuration Table of Column Translation', 'The table defines translation for Excel table headers and ribbon fields');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_dev', 'event_handlers', 'en', NULL, 'Configuration Table of Excel Event Handlers', 'The table defines Excel event handlers and Actions and Context Menu items');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_dev', 'object_translation', 'en', NULL, 'Configuration Table of Object Translation', 'The table defines translation for Query List, Actions and Context Menu items');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_dev', 'parameter_values', 'en', NULL, 'Configuration Table of Parameter Value Queries', 'The table defines objects to select ribbon parameter values');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_dev', 'query_list', 'en', NULL, 'Configuration Table of Query List', 'The table defines configuration of Query List objects');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_dev', 'table_format_save', 'en', NULL, 'Configuration Procedure to Save Table Formats', 'The procedure is used to save Excel formats of database objects');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_dev', 'table_formats', 'en', NULL, 'Configuration Table of Excel Table Formats', 'The table contains Excel formats of database objects');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_xls', 'view_column_translation', 'en', NULL, 'Configuration View of Column Translation', NULL);
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_xls', 'view_event_handlers', 'en', NULL, 'Configuration View of Excel Event Handlers', NULL);
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_xls', 'view_object_description', 'en', 'Object Descriptions', 'Database Object Descriptions', 'You may use Query List to connect to these objects');
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_xls', 'view_object_translation', 'en', NULL, 'Configuration View of Object Translation', NULL);
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_xls', 'view_parameter_values', 'en', NULL, 'Configuration View of Parameter Value Queries', NULL);
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_xls', 'view_query_list', 'en', 'Framework Query List', 'Configuration View of Query List', NULL);
INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('savetodb_xls', 'view_table_formats', 'en', NULL, 'Configuration View of Excel Table Formats', NULL);

INSERT INTO savetodb_dev.object_translation (table_schema, table_name, language_name, translated_name, translated_desc, translated_comment) VALUES ('HTTP', 'Online Help', 'en', 'Online Help', NULL, NULL);

INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'query_list', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'query_list', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'query_list', 'table_name', 'en', NULL, 'Database object name or unique name for SQL-code and http-query');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'query_list', 'table_type', 'en', NULL, 'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'query_list', 'insert_procedure', 'en', NULL, 'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'query_list', 'update_procedure', 'en', NULL, 'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'query_list', 'delete_procedure', 'en', NULL, 'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'table_name', 'en', NULL, 'Database object name, SQL-code name, or http-query name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'column_name', 'en', NULL, 'Column name or NULL to use the handler for entire table');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'event_name', 'en', NULL, 'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'handler_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'handler_name', 'en', NULL, 'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'handler_type', 'en', NULL, 'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'target_worksheet', 'en', NULL, 'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'menu_order', 'en', NULL, 'Sort order of Actions and Context Menu items');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'event_handlers', 'edit_parameters', 'en', NULL, 'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'parameter_values', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'parameter_values', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'parameter_values', 'table_name', 'en', NULL, 'Database object name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'parameter_values', 'parameter_name', 'en', NULL, 'Column or parameter name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'parameter_values', 'select_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'parameter_values', 'select_name', 'en', NULL, 'Database object name or name for SQL-code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'parameter_values', 'select_type', 'en', NULL, 'Database object type or CODE for SQL-code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'object_translation', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'object_translation', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'object_translation', 'table_name', 'en', NULL, 'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'object_translation', 'language_name', 'en', NULL, 'Two-char language code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'object_translation', 'translated_name', 'en', NULL, 'Translated name for Query List, Actions and Context Menus');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'object_translation', 'translated_desc', 'en', NULL, 'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'object_translation', 'translated_comment', 'en', NULL, 'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'column_translation', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'column_translation', 'table_schema', 'en', NULL, 'Database object schema or NULL for entire database scope');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'column_translation', 'table_name', 'en', NULL, 'Database object name or NULL for entire schema scope');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'column_translation', 'column_name', 'en', NULL, 'Column or parameter name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'column_translation', 'language_name', 'en', NULL, 'Two-char language code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'column_translation', 'translated_name', 'en', NULL, 'Translated name for Excel table headers and ribbon parameters');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_dev', 'column_translation', 'translated_desc', 'en', NULL, 'Text for Excel table header comments and ribbon parameter SuperTips');

INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_query_list', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_query_list', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_query_list', 'table_name', 'en', NULL, 'Database object name or unique name for SQL-code and http-query');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_query_list', 'table_type', 'en', NULL, 'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_query_list', 'insert_procedure', 'en', NULL, 'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_query_list', 'update_procedure', 'en', NULL, 'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_query_list', 'delete_procedure', 'en', NULL, 'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'table_name', 'en', NULL, 'Database object name, SQL-code name, or http-query name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'column_name', 'en', NULL, 'Column name or NULL to use the handler for entire table');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'event_name', 'en', NULL, 'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'handler_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'handler_name', 'en', NULL, 'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'handler_type', 'en', NULL, 'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'target_worksheet', 'en', NULL, 'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'menu_order', 'en', NULL, 'Sort order of Actions and Context Menu items');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_event_handlers', 'edit_parameters', 'en', NULL, 'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_parameter_values', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_parameter_values', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_parameter_values', 'table_name', 'en', NULL, 'Database object name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_parameter_values', 'parameter_name', 'en', NULL, 'Column or parameter name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_parameter_values', 'select_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_parameter_values', 'select_name', 'en', NULL, 'Database object name or name for SQL-code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_parameter_values', 'select_type', 'en', NULL, 'Database object type or CODE for SQL-code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_object_translation', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_object_translation', 'table_schema', 'en', NULL, 'Database object schema');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_object_translation', 'table_name', 'en', NULL, 'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_object_translation', 'language_name', 'en', NULL, 'Two-char language code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_object_translation', 'translated_name', 'en', NULL, 'Translated name for Query List, Actions and Context Menus');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_object_translation', 'translated_desc', 'en', NULL, 'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_object_translation', 'translated_comment', 'en', NULL, 'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_column_translation', 'id', 'en', NULL, NULL);
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_column_translation', 'table_schema', 'en', NULL, 'Database object schema or NULL for entire database scope');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_column_translation', 'table_name', 'en', NULL, 'Database object name or NULL for entire schema scope');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_column_translation', 'column_name', 'en', NULL, 'Column or parameter name');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_column_translation', 'language_name', 'en', NULL, 'Two-char language code');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_column_translation', 'translated_name', 'en', NULL, 'Translated name for Excel table headers and ribbon parameters');
INSERT INTO savetodb_dev.column_translation (table_schema, table_name, column_name, language_name, translated_name, translated_desc) VALUES ('savetodb_xls', 'view_column_translation', 'translated_desc', 'en', NULL, 'Text for Excel table header comments and ribbon parameter SuperTips');

INSERT INTO savetodb_dev.table_formats (table_schema, table_name, table_excel_format_xml) VALUES ('savetodb_xls', 'view_object_description', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_xls.view_object_description">
<columnFormats>
<column name="" property="ListObjectName" value="UserObjects_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="language_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="language_name" property="Address" value="$C$7" type="String" />
<column name="language_name" property="ColumnWidth" value="0.08" type="Double" />
<column name="language_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="table_schema" property="Address" value="$D$7" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="table_name" property="Address" value="$E$7" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="translated_name" property="Address" value="$F$7" type="String" />
<column name="translated_name" property="ColumnWidth" value="24" type="Double" />
<column name="translated_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="translated_comment" property="Address" value="$G$7" type="String" />
<column name="translated_comment" property="ColumnWidth" value="108.86" type="Double" />
<column name="translated_comment" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_comment" property="WrapText" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="False" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="False" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="-6" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');


INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','query_list','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.query_list">
<columnFormats>
<column name="" property="ListObjectName" value="QueryList" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="15" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="22.86" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_type" property="Address" value="$F$4" type="String" />
<column name="table_type" property="ColumnWidth" value="12.14" type="Double" />
<column name="table_type" property="NumberFormat" value="General" type="String" />
<column name="table_type" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_type" property="Validation.Type" value="3" type="Double" />
<column name="table_type" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_type" property="Validation.Operator" value="1" type="Double" />
<column name="table_type" property="Validation.Formula1" value="TABLE;VIEW;FUNCTION;CODE;HTTP;TEXT" type="String" />
<column name="table_type" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_type" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_type" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_type" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_code" property="Address" value="$G$4" type="String" />
<column name="table_code" property="ColumnWidth" value="12.86" type="Double" />
<column name="table_code" property="NumberFormat" value="General" type="String" />
<column name="table_code" property="VerticalAlignment" value="-4160" type="Double" />
<column name="insert_procedure" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="insert_procedure" property="Address" value="$H$4" type="String" />
<column name="insert_procedure" property="ColumnWidth" value="30" type="Double" />
<column name="insert_procedure" property="NumberFormat" value="General" type="String" />
<column name="insert_procedure" property="VerticalAlignment" value="-4160" type="Double" />
<column name="update_procedure" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="update_procedure" property="Address" value="$I$4" type="String" />
<column name="update_procedure" property="ColumnWidth" value="30" type="Double" />
<column name="update_procedure" property="NumberFormat" value="General" type="String" />
<column name="update_procedure" property="VerticalAlignment" value="-4160" type="Double" />
<column name="delete_procedure" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="delete_procedure" property="Address" value="$J$4" type="String" />
<column name="delete_procedure" property="ColumnWidth" value="29.86" type="Double" />
<column name="delete_procedure" property="NumberFormat" value="General" type="String" />
<column name="delete_procedure" property="VerticalAlignment" value="-4160" type="Double" />
<column name="procedure_type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="procedure_type" property="Address" value="$K$4" type="String" />
<column name="procedure_type" property="ColumnWidth" value="17.14" type="Double" />
<column name="procedure_type" property="NumberFormat" value="General" type="String" />
<column name="procedure_type" property="VerticalAlignment" value="-4160" type="Double" />
<column name="procedure_type" property="Validation.Type" value="3" type="Double" />
<column name="procedure_type" property="Validation.AlertStyle" value="1" type="Double" />
<column name="procedure_type" property="Validation.Operator" value="1" type="Double" />
<column name="procedure_type" property="Validation.Formula1" value="TABLE;PROCEDURE;CODE;MERGE" type="String" />
<column name="procedure_type" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="procedure_type" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="procedure_type" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="procedure_type" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','event_handlers','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.event_handlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="ColumnWidth" value="11.71" type="Double" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="15" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="22.86" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="column_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="column_name" property="Address" value="$F$4" type="String" />
<column name="column_name" property="ColumnWidth" value="15.71" type="Double" />
<column name="column_name" property="NumberFormat" value="General" type="String" />
<column name="column_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="column_name" property="Validation.Type" value="6" type="Double" />
<column name="column_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="column_name" property="Validation.Operator" value="8" type="Double" />
<column name="column_name" property="Validation.Formula1" value="64" type="String" />
<column name="column_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="column_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="event_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="event_name" property="Address" value="$G$4" type="String" />
<column name="event_name" property="ColumnWidth" value="15" type="Double" />
<column name="event_name" property="NumberFormat" value="General" type="String" />
<column name="event_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="event_name" property="Validation.Type" value="3" type="Double" />
<column name="event_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="event_name" property="Validation.Operator" value="8" type="Double" />
<column name="event_name" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="event_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="event_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="event_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="event_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_schema" property="Address" value="$H$4" type="String" />
<column name="handler_schema" property="ColumnWidth" value="17.14" type="Double" />
<column name="handler_schema" property="NumberFormat" value="General" type="String" />
<column name="handler_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_name" property="Address" value="$I$4" type="String" />
<column name="handler_name" property="ColumnWidth" value="35.71" type="Double" />
<column name="handler_name" property="NumberFormat" value="General" type="String" />
<column name="handler_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_name" property="Validation.Type" value="6" type="Double" />
<column name="handler_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="handler_name" property="Validation.Operator" value="8" type="Double" />
<column name="handler_name" property="Validation.Formula1" value="2000" type="String" />
<column name="handler_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="handler_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="handler_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="handler_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_type" property="Address" value="$J$4" type="String" />
<column name="handler_type" property="ColumnWidth" value="14.29" type="Double" />
<column name="handler_type" property="NumberFormat" value="General" type="String" />
<column name="handler_type" property="VerticalAlignment" value="-4160" type="Double" />
<column name="handler_type" property="Validation.Type" value="3" type="Double" />
<column name="handler_type" property="Validation.AlertStyle" value="1" type="Double" />
<column name="handler_type" property="Validation.Operator" value="1" type="Double" />
<column name="handler_type" property="Validation.Formula1" value="TABLE;VIEW;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String" />
<column name="handler_type" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="handler_type" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="handler_type" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="handler_type" property="Validation.ShowError" value="True" type="Boolean" />
<column name="handler_code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="handler_code" property="Address" value="$K$4" type="String" />
<column name="handler_code" property="ColumnWidth" value="42.14" type="Double" />
<column name="handler_code" property="NumberFormat" value="General" type="String" />
<column name="handler_code" property="VerticalAlignment" value="-4160" type="Double" />
<column name="target_worksheet" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="target_worksheet" property="Address" value="$L$4" type="String" />
<column name="target_worksheet" property="ColumnWidth" value="22.86" type="Double" />
<column name="target_worksheet" property="NumberFormat" value="General" type="String" />
<column name="target_worksheet" property="VerticalAlignment" value="-4160" type="Double" />
<column name="target_worksheet" property="Validation.Type" value="6" type="Double" />
<column name="target_worksheet" property="Validation.AlertStyle" value="1" type="Double" />
<column name="target_worksheet" property="Validation.Operator" value="8" type="Double" />
<column name="target_worksheet" property="Validation.Formula1" value="64" type="String" />
<column name="target_worksheet" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="target_worksheet" property="Validation.ShowError" value="True" type="Boolean" />
<column name="menu_order" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="menu_order" property="Address" value="$M$4" type="String" />
<column name="menu_order" property="ColumnWidth" value="13.57" type="Double" />
<column name="menu_order" property="NumberFormat" value="General" type="String" />
<column name="menu_order" property="VerticalAlignment" value="-4160" type="Double" />
<column name="menu_order" property="Validation.Type" value="1" type="Double" />
<column name="menu_order" property="Validation.AlertStyle" value="1" type="Double" />
<column name="menu_order" property="Validation.Operator" value="1" type="Double" />
<column name="menu_order" property="Validation.Formula1" value="-32768" type="String" />
<column name="menu_order" property="Validation.Formula2" value="32767" type="String" />
<column name="menu_order" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="menu_order" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="menu_order" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="menu_order" property="Validation.ShowError" value="True" type="Boolean" />
<column name="edit_parameters" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="edit_parameters" property="Address" value="$N$4" type="String" />
<column name="edit_parameters" property="ColumnWidth" value="17.43" type="Double" />
<column name="edit_parameters" property="NumberFormat" value="General" type="String" />
<column name="edit_parameters" property="VerticalAlignment" value="-4160" type="Double" />
<column name="edit_parameters" property="Validation.Type" value="1" type="Double" />
<column name="edit_parameters" property="Validation.AlertStyle" value="1" type="Double" />
<column name="edit_parameters" property="Validation.Operator" value="1" type="Double" />
<column name="edit_parameters" property="Validation.Formula1" value="-32768" type="String" />
<column name="edit_parameters" property="Validation.Formula2" value="32767" type="String" />
<column name="edit_parameters" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="edit_parameters" property="Validation.ShowError" value="True" type="Boolean" />
<column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="is_active" property="Address" value="$O$4" type="String" />
<column name="is_active" property="ColumnWidth" value="10.29" type="Double" />
<column name="is_active" property="NumberFormat" value="General" type="String" />
<column name="is_active" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="event_name" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="SortFields(4)" property="KeyfieldName" value="menu_order" type="String" />
<column name="SortFields(4)" property="SortOn" value="0" type="Double" />
<column name="SortFields(4)" property="Order" value="1" type="Double" />
<column name="SortFields(4)" property="DataOption" value="0" type="Double" />
<column name="SortFields(5)" property="KeyfieldName" value="handler_name" type="String" />
<column name="SortFields(5)" property="SortOn" value="0" type="Double" />
<column name="SortFields(5)" property="Order" value="1" type="Double" />
<column name="SortFields(5)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','parameter_values','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.parameter_values">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="14.57" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="16.43" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="parameter_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="parameter_name" property="Address" value="$F$4" type="String" />
<column name="parameter_name" property="ColumnWidth" value="17.86" type="Double" />
<column name="parameter_name" property="NumberFormat" value="General" type="String" />
<column name="parameter_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="parameter_name" property="Validation.Type" value="6" type="Double" />
<column name="parameter_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="parameter_name" property="Validation.Operator" value="8" type="Double" />
<column name="parameter_name" property="Validation.Formula1" value="64" type="String" />
<column name="parameter_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="parameter_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="parameter_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="parameter_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_schema" property="Address" value="$G$4" type="String" />
<column name="select_schema" property="ColumnWidth" value="15.71" type="Double" />
<column name="select_schema" property="NumberFormat" value="General" type="String" />
<column name="select_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="select_schema" property="Validation.Type" value="6" type="Double" />
<column name="select_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="select_schema" property="Validation.Operator" value="8" type="Double" />
<column name="select_schema" property="Validation.Formula1" value="64" type="String" />
<column name="select_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="select_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="select_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="select_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_name" property="Address" value="$H$4" type="String" />
<column name="select_name" property="ColumnWidth" value="30" type="Double" />
<column name="select_name" property="NumberFormat" value="General" type="String" />
<column name="select_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="select_name" property="Validation.Type" value="6" type="Double" />
<column name="select_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="select_name" property="Validation.Operator" value="8" type="Double" />
<column name="select_name" property="Validation.Formula1" value="64" type="String" />
<column name="select_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="select_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="select_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="select_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_type" property="Address" value="$I$4" type="String" />
<column name="select_type" property="ColumnWidth" value="12.86" type="Double" />
<column name="select_type" property="NumberFormat" value="General" type="String" />
<column name="select_type" property="VerticalAlignment" value="-4160" type="Double" />
<column name="select_type" property="Validation.Type" value="3" type="Double" />
<column name="select_type" property="Validation.AlertStyle" value="1" type="Double" />
<column name="select_type" property="Validation.Operator" value="8" type="Double" />
<column name="select_type" property="Validation.Formula1" value="TABLE;VIEW;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String" />
<column name="select_type" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="select_type" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="select_type" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="select_type" property="Validation.ShowError" value="True" type="Boolean" />
<column name="select_code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="select_code" property="Address" value="$J$4" type="String" />
<column name="select_code" property="ColumnWidth" value="58.86" type="Double" />
<column name="select_code" property="NumberFormat" value="General" type="String" />
<column name="select_code" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="parameter_name" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','object_translation','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.object_translation">
<columnFormats>
<column name="" property="ListObjectName" value="ObjectTranslation" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.29" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="id" property="Validation.ErrorMessage" value="The column requires values of the integer datatype." type="String" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="15" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="35.71" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="language_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="language_name" property="Address" value="$F$4" type="String" />
<column name="language_name" property="ColumnWidth" value="3.14" type="Double" />
<column name="language_name" property="NumberFormat" value="General" type="String" />
<column name="language_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="language_name" property="Validation.Type" value="6" type="Double" />
<column name="language_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="language_name" property="Validation.Operator" value="8" type="Double" />
<column name="language_name" property="Validation.Formula1" value="2" type="String" />
<column name="language_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="language_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="language_name" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="language_name" property="Validation.ErrorMessage" value="The column requires values of the character(2) datatype." type="String" />
<column name="language_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="language_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="translated_name" property="Address" value="$G$4" type="String" />
<column name="translated_name" property="ColumnWidth" value="26.14" type="Double" />
<column name="translated_name" property="NumberFormat" value="General" type="String" />
<column name="translated_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_name" property="Validation.Type" value="6" type="Double" />
<column name="translated_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="translated_name" property="Validation.Operator" value="8" type="Double" />
<column name="translated_name" property="Validation.Formula1" value="64" type="String" />
<column name="translated_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="translated_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="translated_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="translated_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="translated_desc" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="translated_desc" property="Address" value="$H$4" type="String" />
<column name="translated_desc" property="ColumnWidth" value="43.86" type="Double" />
<column name="translated_desc" property="NumberFormat" value="General" type="String" />
<column name="translated_desc" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_desc" property="Validation.Type" value="6" type="Double" />
<column name="translated_desc" property="Validation.AlertStyle" value="1" type="Double" />
<column name="translated_desc" property="Validation.Operator" value="8" type="Double" />
<column name="translated_desc" property="Validation.Formula1" value="256" type="String" />
<column name="translated_desc" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="translated_desc" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="translated_desc" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="translated_desc" property="Validation.ShowError" value="True" type="Boolean" />
<column name="translated_comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="translated_comment" property="Address" value="$I$4" type="String" />
<column name="translated_comment" property="ColumnWidth" value="69.71" type="Double" />
<column name="translated_comment" property="NumberFormat" value="General" type="String" />
<column name="translated_comment" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_comment" property="Validation.Type" value="6" type="Double" />
<column name="translated_comment" property="Validation.AlertStyle" value="1" type="Double" />
<column name="translated_comment" property="Validation.Operator" value="8" type="Double" />
<column name="translated_comment" property="Validation.Formula1" value="2000" type="String" />
<column name="translated_comment" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="translated_comment" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="translated_comment" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="translated_comment" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="language_name" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO savetodb_dev.table_formats ("table_schema","table_name","table_excel_format_xml") VALUES ('savetodb_dev','column_translation','<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.column_translation">
<columnFormats>
<column name="" property="ListObjectName" value="ColumnTranslation" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="NumberFormat" value="General" type="String" />
<column name="id" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$4" type="String" />
<column name="table_schema" property="ColumnWidth" value="15" type="Double" />
<column name="table_schema" property="NumberFormat" value="General" type="String" />
<column name="table_schema" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$4" type="String" />
<column name="table_name" property="ColumnWidth" value="22.86" type="Double" />
<column name="table_name" property="NumberFormat" value="General" type="String" />
<column name="table_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="column_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="column_name" property="Address" value="$F$4" type="String" />
<column name="column_name" property="ColumnWidth" value="19" type="Double" />
<column name="column_name" property="NumberFormat" value="General" type="String" />
<column name="column_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="column_name" property="Validation.Type" value="6" type="Double" />
<column name="column_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="column_name" property="Validation.Operator" value="8" type="Double" />
<column name="column_name" property="Validation.Formula1" value="64" type="String" />
<column name="column_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="column_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="column_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="language_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="language_name" property="Address" value="$G$4" type="String" />
<column name="language_name" property="ColumnWidth" value="3.57" type="Double" />
<column name="language_name" property="NumberFormat" value="General" type="String" />
<column name="language_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="language_name" property="Validation.Type" value="6" type="Double" />
<column name="language_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="language_name" property="Validation.Operator" value="8" type="Double" />
<column name="language_name" property="Validation.Formula1" value="2" type="String" />
<column name="language_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="language_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="language_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="language_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="translated_name" property="Address" value="$H$4" type="String" />
<column name="translated_name" property="ColumnWidth" value="18.29" type="Double" />
<column name="translated_name" property="NumberFormat" value="General" type="String" />
<column name="translated_name" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_name" property="Validation.Type" value="6" type="Double" />
<column name="translated_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="translated_name" property="Validation.Operator" value="8" type="Double" />
<column name="translated_name" property="Validation.Formula1" value="64" type="String" />
<column name="translated_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="translated_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="translated_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="translated_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="translated_desc" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="translated_desc" property="Address" value="$I$4" type="String" />
<column name="translated_desc" property="ColumnWidth" value="68.57" type="Double" />
<column name="translated_desc" property="NumberFormat" value="General" type="String" />
<column name="translated_desc" property="VerticalAlignment" value="-4160" type="Double" />
<column name="translated_desc" property="Validation.Type" value="6" type="Double" />
<column name="translated_desc" property="Validation.AlertStyle" value="1" type="Double" />
<column name="translated_desc" property="Validation.Operator" value="8" type="Double" />
<column name="translated_desc" property="Validation.Formula1" value="1024" type="String" />
<column name="translated_desc" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="translated_desc" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="translated_desc" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="translated_desc" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="language_name" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="table_schema" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="table_name" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="2" type="Double" />
<column name="SortFields(4)" property="KeyfieldName" value="column_name" type="String" />
<column name="SortFields(4)" property="SortOn" value="0" type="Double" />
<column name="SortFields(4)" property="Order" value="1" type="Double" />
<column name="SortFields(4)" property="DataOption" value="2" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');


INSERT INTO savetodb_dev.table_formats (table_schema, table_name, table_excel_format_xml) VALUES ('savetodb_dev', 'table_formats', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.table_formats">
<columnFormats>
<column name="" property="ListObjectName" value="UserObjects_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="Address" value="$C$7" type="String" />
<column name="id" property="ColumnWidth" value="4.43" type="Double" />
<column name="id" property="Validation.Type" value="1" type="Double" />
<column name="id" property="Validation.AlertStyle" value="1" type="Double" />
<column name="id" property="Validation.Operator" value="1" type="Double" />
<column name="id" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="id" property="Validation.Formula2" value="2147483647" type="String" />
<column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="id" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="id" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_schema" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_schema" property="Address" value="$D$7" type="String" />
<column name="table_schema" property="ColumnWidth" value="16.57" type="Double" />
<column name="table_schema" property="Validation.Type" value="6" type="Double" />
<column name="table_schema" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_schema" property="Validation.Operator" value="8" type="Double" />
<column name="table_schema" property="Validation.Formula1" value="64" type="String" />
<column name="table_schema" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_schema" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_schema" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_name" property="Address" value="$E$7" type="String" />
<column name="table_name" property="ColumnWidth" value="22.57" type="Double" />
<column name="table_name" property="Validation.Type" value="6" type="Double" />
<column name="table_name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="table_name" property="Validation.Operator" value="8" type="Double" />
<column name="table_name" property="Validation.Formula1" value="64" type="String" />
<column name="table_name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="table_name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="table_name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="table_excel_format_xml" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="table_excel_format_xml" property="Address" value="$F$7" type="String" />
<column name="table_excel_format_xml" property="ColumnWidth" value="70.71" type="Double" />
<column name="table_schema" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$13" type="String" />
<column name="table_schema" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="table_schema" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="table_schema" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="table_schema" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="table_schema" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="table_schema" property="FormatConditions(2).ColumnsCount" value="2" type="Double" />
<column name="table_schema" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$E$13" type="String" />
<column name="table_schema" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="table_schema" property="FormatConditions(2).Priority" value="4" type="Double" />
<column name="table_schema" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="table_schema" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="table_schema" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="table_name" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$13" type="String" />
<column name="table_name" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="table_name" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="table_name" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="table_name" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="table_name" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="False" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="False" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="-6" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

-- print SaveToDB Framework data have been added

-- print SaveToDB Framework has been installed
